@@ -1,5 +1,5 @@
 package Dist::Zilla::Plugin::Changes;
-$Dist::Zilla::Plugin::Changes::VERSION = '0.002';
+$Dist::Zilla::Plugin::Changes::VERSION = '0.003';
 use Moose;
 with qw/Dist::Zilla::Role::FileGatherer/;
 use MooseX::Types::Moose qw/Str Int/;
@@ -60,14 +60,14 @@ Dist::Zilla::Plugin::Changes - Create a changes file
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
 In your profile.ini
 
  [Changes]
- initial = Initial release
+ initial = - Initial release
 
 =head1 DESCRIPTION
 
@@ -81,7 +81,7 @@ This sets the filename of the changelog. It defaults to C<Changes>.
 
 =head2 initial
 
-This is default entry for the initial version. This could be something like C<Initial release>. If not set, no such line is added.
+This is default entry for the initial version. This could be something like C<- Initial release>. If not set, no such line is added.
 
 =head2 indent
 
